@@ -3,15 +3,18 @@ use warnings;
 
 package Mail::Box::Manager;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.068';
 use base 'Mail::Reporter';
 
 use Mail::Box;
 
-use Carp;
 use List::Util   'first';
 use Scalar::Util 'weaken';
 
+# failed compilation will not complain a second time
+# so we need to keep track.
+my %require_failed;
+
 #-------------------------------------------
 
 
@@ -21,6 +24,8 @@ my @basic_folder_types =
   , [ maildir => 'Mail::Box::Maildir' ]
   , [ pop     => 'Mail::Box::POP3'    ]
   , [ pop3    => 'Mail::Box::POP3'    ]
+  , [ imap    => 'Mail::Box::IMAP4'   ]
+  , [ imap4   => 'Mail::Box::IMAP4'   ]
   );
 
 my @managers;  # usually only one, but there may be more around :(
@@ -47,11 +52,10 @@ sub init($)
     $self->{MBM_folder_types} = [];
     $self->registerType(@$_) foreach @new_types, @basic_types;
 
-    $self->{MBM_default_type} = $args->{default_folder_type};
+    $self->{MBM_default_type} = $args->{default_folder_type} || 'mbox';
 
     # Inventory on existing folder-directories.
-
-    $self->{MBM_folderdirs} = [ '.' ];
+    $self->{MBM_folderdirs} = [ ];
     if(exists $args->{folderdir})
     {   my @dirs = $args->{folderdir};
         @dirs = @{$dirs[0]} if ref $dirs[0];
@@ -63,6 +67,7 @@ sub init($)
         @dirs = @{$dirs[0]} if ref $dirs[0];
         push @{$self->{MBM_folderdirs}}, @dirs;
     }
+    push @{$self->{MBM_folderdirs}}, '.';
 
     $self->{MBM_folders} = [];
     $self->{MBM_threads} = [];
@@ -85,6 +90,14 @@ sub registerType($$@)
 #-------------------------------------------
 
 
+sub folderdir()
+{   my $dirs = shift->{MBM_folderdirs} or return ();
+    wantarray ? @$dirs : $dirs->[0];
+}
+
+#-------------------------------------------
+
+
 sub folderTypes()
 {   my $self = shift;
     my %uniq;
@@ -92,6 +105,20 @@ sub folderTypes()
     sort keys %uniq;
 }
 
+#-------------------------------------------
+
+
+sub defaultFolderType()
+{   my $self = shift;
+    my $name = $self->{MBM_default_type};
+    return $name if $name =~ m/\:\:/;  # obviously a class name
+
+    foreach my $def (@{$self->{MBM_folder_types}})
+    {   return $def->[1] if $def->[0] eq $name || $def->[1] eq $name;
+    }
+
+    undef;
+}
 
 #-------------------------------------------
 
@@ -100,15 +127,11 @@ sub open(@)
 {   my $self = shift;
     my $name = @_ % 2 ? shift : undef;
     my %args = @_;
+    $args{authentication} ||= 'AUTO';
 
-    $name    = defined $args{folder} ? $args{folder} : $ENV{MAIL}
+    $name    = defined $args{folder} ? $args{folder} : ($ENV{MAIL} || '')
         unless defined $name;
 
-    unless(defined $name)
-    {   $self->log(ERROR => "Don't know which folder I should open: no name.");
-        return undef;
-    }
-      
     if($name =~ m/^(\w+)\:/ && grep { $_ eq $1 } $self->folderTypes)
     {   # Complicated folder URL
         my %decoded = $self->decodeFolderURL($name);
@@ -126,8 +149,16 @@ sub open(@)
         $args{folder} = $name;
     }
 
+    my $type = $args{type};
+    if(defined $type && $type eq 'pop3')
+    {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
+        my $srv  = $args{server_name} ||= 'localhost';
+        my $port = $args{server_port} ||= 110;
+        $args{folder} = $name = "pop3://$un\@$srv:$port";
+    }
+
     unless(defined $name && length $name)
-    {   $self->log(ERROR => "No foldername specified to open.\n");
+    {   $self->log(ERROR => "No foldername specified to open.");
         return undef;
     }
         
@@ -144,7 +175,7 @@ sub open(@)
 
     # Do not open twice.
     if(my $folder = $self->isOpenFolder($name))
-    {   $self->log(WARNING => "Folder $name is already open.\n");
+    {   $self->log(ERROR => "Folder $name is already open.");
         return undef;
     }
 
@@ -153,7 +184,7 @@ sub open(@)
     #
 
     my ($folder_type, $class, @defaults);
-    if(my $type = $args{type})
+    if($type)
     {   # User-specified foldertype prevails.
         foreach (@{$self->{MBM_folder_types}})
         {   (my $abbrev, $class, @defaults) = @$_;
@@ -171,10 +202,15 @@ sub open(@)
     unless($folder_type)
     {   # Try to autodetect foldertype.
         foreach (@{$self->{MBM_folder_types}})
-        {   (my $abbrev, $class, @defaults) = @$_;
+        {   next unless $_;
+            (my $abbrev, $class, @defaults) = @$_;
+            next if $require_failed{$class};
 
-            eval("require $class");
-            next if $@;
+            eval "require $class";
+            if($@)
+            {   $require_failed{$class}++;
+                next;
+            }
 
             if($class->foundIn($name, @defaults, %args))
             {   $folder_type = $abbrev;
@@ -205,14 +241,20 @@ sub open(@)
     # Try to open the folder
     #
 
+    return if $require_failed{$class};
     eval "require $class";
-    croak $@ if $@;
+    if($@)
+    {   $self->log(ERROR => "Failed for folder default $class: $@");
+        $require_failed{$class}++;
+        return ();
+    }
 
     push @defaults, manager => $self;
     my $folder = $class->new(@defaults, %args);
-
     unless(defined $folder)
-    {   $self->log(WARNING =>"Folder does not exist, failed opening $folder_type folder $name.");
+    {   $self->log(WARNING =>
+           "Folder does not exist, failed opening $folder_type folder $name.")
+           unless $args{access} eq 'd';
         return;
     }
 
@@ -238,7 +280,7 @@ sub isOpenFolder($)
 
 
 sub close($@)
-{   my ($self, $folder, @options) = @_;
+{   my ($self, $folder, %options) = @_;
     return unless $folder;
 
     my $name      = $folder->name;
@@ -250,7 +292,9 @@ sub close($@)
     $self->{MBM_folders} = [ @remaining ];
     $_->removeFolder($folder) foreach @{$self->{MBM_threads}};
 
-    $folder->close(close_by_manager => 1, @options);
+    $folder->close(close_by_manager => 1, %options)
+       unless $options{close_by_self};
+
     $self;
 }
 
@@ -269,9 +313,13 @@ END {map {defined $_ && $_->closeAllFolders} @managers}
 
 
 sub delete($@)
-{   my ($self, $name, @options) = @_;
-    my $folder = $self->open(folder => $name, @options) or return;
-    $folder->delete;
+{   my ($self, $name, %args) = @_;
+    my $recurse = delete $args{recursive};
+
+    my $folder = $self->open(folder => $name, access => 'd', %args)
+        or return $self;  # still successful
+
+    $folder->delete(recursive => $recurse);
 }
 
 #-------------------------------------------
@@ -322,8 +370,12 @@ sub appendMessages(@)
 
     foreach (@{$self->{MBM_folder_types}})
     {   ($name, $class, @gen_options) = @$_;
+        next if $require_failed{$class};
         eval "require $class";
-        next if $@;
+        if($@)
+        {   $require_failed{$class}++;
+            next;
+        }
 
         if($class->foundIn($folder, @gen_options, access => 'a'))
         {   $found++;
@@ -373,8 +425,9 @@ sub copyMessage(@)
         push @messages, $message;
     }
 
-    my %options = @_;
-    $folder ||= $options{folder};
+    my %args = @_;
+    $folder ||= $args{folder};
+    my $share   = exists $args{share} ? $args{share} : $args{_delete};
 
     # Try to resolve filenames into opened-files.
     $folder = $self->isOpenFolder($folder) || $folder
@@ -382,11 +435,11 @@ sub copyMessage(@)
 
     my @coerced
      = ref $folder
-     ? map {$_->copyTo($folder)} @messages
-     : $self->appendMessages(@messages, %options, folder => $folder);
+     ? map {$_->copyTo($folder, share => $args{share})} @messages
+     : $self->appendMessages(@messages, %args, folder => $folder);
 
     # hidden option, do not use it: it's designed to optimize moveMessage
-    if($options{_delete})
+    if($args{_delete})
     {   $_->label(deleted => 1) foreach @messages;
     }
 
@@ -424,7 +477,7 @@ sub threads(@)
        :                           $folders
        );
 
-    $self->log(INTERNAL => "No folders specified.\n")
+    $self->log(INTERNAL => "No folders specified.")
        unless @folders;
 
     my $threads;
@@ -439,6 +492,7 @@ sub threads(@)
         # need to compile Mail::Box::Thread::Manager when no threads are needed.
         eval "require $type";
         $self->log(INTERNAL => "Unusable threader $type: $@") if $@;
+
         $self->log(INTERNAL => "You need to pass a $base derived")
             unless $type->isa($base);
 
@@ -488,10 +542,11 @@ sub decodeFolderURL($)
     $username ||= $ENV{USER} || $ENV{LOGNAME};
 
     $password ||= '';        # decode password from url
-    $password =~ s/\+/ /g;
-    $password =~ s/\%([A-Fa-f0-9]{2})/chr hex $1/ge;
+    $password   =~ s/\+/ /g;
+    $password   =~ s/\%([A-Fa-f0-9]{2})/chr hex $1/ge;
 
     $hostname ||= 'localhost';
+
     $path     ||= '=';
 
     ( type        => $type,     folder      => $path
@@ -503,4 +558,5 @@ sub decodeFolderURL($)
 #-------------------------------------------
 
 
+
 1;
