@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Body::Lines;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.068';
 use base 'Mail::Message::Body';
 
 use Mail::Box::Parser;
@@ -31,7 +31,8 @@ sub _data_from_filename(@)
 
 sub _data_from_filehandle(@)
 {   my ($self, $fh) = @_;
-    $self->{MMBL_array} = [ $fh->getlines ];
+    $self->{MMBL_array} =
+       ref $fh eq 'Mail::Box::FastScalar' ? $fh->getlines : [ $fh->getlines ];
     $self
 }
 
@@ -79,7 +80,7 @@ sub string() { join '', @{shift->{MMBL_array}} }
 
 #------------------------------------------
 
-sub lines()  { wantarray ? @{shift->{MMBL_array}} : shift->{MMBL_array} }
+sub lines() { wantarray ? @{shift->{MMBL_array}} : shift->{MMBL_array} }
 
 #------------------------------------------
 
@@ -97,35 +98,21 @@ sub print(;$)
 
 #------------------------------------------
 
-sub printEscapedFrom($)
-{   my ($self, $fh) = @_;
-
-    if(ref $fh eq 'GLOB')
-    {   foreach ( @{$self->{MMBL_array}} )
-        {   s/^(?=\>*From )/>/;
-            print $fh;
-        }
-    }
-    else
-    {   foreach ( @{$self->{MMBL_array}} )
-        {   s/^(?=\>*From )/>/;
-            $fh->print($_);
-        }
-    }
+sub read($$;$@)
+{   my ($self, $parser, $head, $bodytype) = splice @_, 0, 4;
+    my ($begin, $end, $lines) = $parser->bodyAsList(@_);
+    $lines or return undef;
 
+    $self->fileLocation($begin, $end);
+    $self->{MMBL_array} = $lines;
     $self;
 }
 
 #------------------------------------------
 
-sub read($$;$@)
-{   my ($self, $parser, $head, $bodytype) = splice @_, 0, 4;
-    my @lines = $parser->bodyAsList(@_);
-    return undef unless @lines;
-
-    $self->fileLocation(shift @lines, shift @lines);
-    $self->{MMBL_array} = \@lines;
-    $self;
+sub endsOnNewline()
+{   my $last = shift->{MMBL_array}[-1];
+    !defined $last || $last =~ m/\n$/;
 }
 
 #------------------------------------------
