@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Body::Nested;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.068';
 use base 'Mail::Message::Body';
 
 use Mail::Message::Body::Lines;
@@ -36,7 +36,7 @@ sub isNested() {1}
 
 #------------------------------------------
 
-sub isBinary() {shift->nested->body->isBinary}
+sub isBinary() { shift->nested->body->isBinary }
 
 #------------------------------------------
 
@@ -88,11 +88,16 @@ sub print(;$)
 
 #------------------------------------------
 
-sub printEscapedFrom($)
-{   my $self = shift;
-    $self->nested->printEscapedFrom(shift);
+
+sub foreachLine($)
+{   my ($self, $code) = @_;
+    $self->log(ERROR => "You cannot use foreachLine on a nested");
+    confess;
 }
 
+
+#------------------------------------------
+
 sub check() { shift->forNested( sub {$_[1]->check} ) }
 
 #------------------------------------------
@@ -130,6 +135,10 @@ sub fileLocation()
     );
 }
 
+#-------------------------------------------
+
+sub endsOnNewline() { shift->nested->body->endsOnNewline }
+
 #------------------------------------------
 
 sub moveLocation($)
