@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '2.060';
+$VERSION = '2.068';
 use base 'Mail::Message::Head';
 
 use Mail::Box::Parser;
@@ -30,6 +30,7 @@ sub build(@)
     my $head = $self->new;
     while(@_)
     {   my $name = shift;
+        defined $name or next;
 
         if($name->isa('Mail::Message::Field'))
         {   $head->add($name);
@@ -37,6 +38,8 @@ sub build(@)
         }
 
         my $content = shift;
+        defined $content or next;
+
         if(ref $content && $content->isa('Mail::Message::Field'))
         {   $self->log(WARNING => "Field objects have an implied name ($name)");
             $head->add($content);
@@ -84,6 +87,8 @@ sub add(@)
       = @_==1 && ref $_[0] ? shift     # A fully qualified field is added.
       : ($self->{MMH_field_type} || 'Mail::Message::Field::Fast')->new(@_);
 
+    return if !defined $field;
+
     $field->setWrapLength;
 
     # Put it in place.
@@ -148,7 +153,9 @@ sub grepNames(@)
 #------------------------------------------
 
 
-my @skip_none = qw/content-transfer-encoding content-disposition/;
+my @skip_none = qw/content-transfer-encoding content-disposition
+                   content-description/;
+
 my %skip_none = map { ($_ => 1) } @skip_none;
 
 sub set(@)
