@@ -4,7 +4,7 @@ use warnings;
 
 package Mail::Message::Replace::MailInternet;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.068';
 use base 'Mail::Message';
 
 use Mail::Box::FastScalar;
@@ -96,9 +96,6 @@ sub processRawData($$$)
 }
 
 
-sub coerce() { confess }
-
-
 sub dup()
 {   my $self = shift;
     ref($self)->coerce($self->clone);
@@ -331,23 +328,23 @@ sub smtpsend(@)
 
 
 sub as_mbox_string()
-{   my $self   = shift;
-    my $head   = $self->head->clone;
-    $head->delete('Content-Length');
+{   my $self    = shift;
+    my $mboxmsg = Mail::Box::Mbox->coerce($self);
 
-    my $buffer = '';
-    my $file   = Mail::Box::FastScalar->new(\$buffer);
-    $head->print($file);
-    $self->body->printEscapedFrom($file);
+    my $buffer  = '';
+    my $file    = Mail::Box::FastScalar->new(\$buffer);
+    $mboxmsg->print($file);
     $buffer;
 }
 
 
-BEGIN { *Mail::Internet::new =
-          sub { my $class = shift;
-                Mail::Message::Replace::MailInternet->new(@_);
-              }
-      }
+BEGIN {
+ no warnings;
+ *Mail::Internet::new =
+    sub { my $class = shift;
+          Mail::Message::Replace::MailInternet->new(@_);
+        }
+}
 
 
 sub isa($)
@@ -357,5 +354,8 @@ sub isa($)
 }
 
 
+sub coerce() { confess }
+
+
 1;
 
