@@ -4,7 +4,7 @@ use warnings;
 
 package Mail::Transport::POP3;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.068';
 use base 'Mail::Transport::Receive';
 
 use IO::Socket  ();
@@ -184,7 +184,7 @@ sub socket(;$)
 {   my $self = shift;
 
     my $socket = $self->_connection;
-    return $socket if $socket;
+    return $socket if defined $socket;
 
     if(exists $self->{MTP_nouidl})
     {   $self->log(ERROR =>
@@ -230,7 +230,7 @@ sub sendList($$)
     return unless OK($response);
 
     my @list;
-    local $_; # make sure we don't spoil it for the outside world
+    local $_;
     while(<$socket>)
     {   last if m#^\.\r?\n#s;
         s#^\.##;
@@ -256,7 +256,9 @@ sub OK($;$) { substr(shift || '', 0, 3) eq '+OK' }
 
 sub _connection(;$)
 {   my $self = shift;
-    my $socket = $self->{MTP_socket} or return undef;
+
+    my $socket = $self->{MTP_socket};
+    defined $socket or return undef;
 
     # Check if we (still) got a connection
     eval {print $socket "NOOP$CRLF"};
@@ -276,7 +278,7 @@ sub login(;$)
 
 # Check if we can make a TCP/IP connection
 
-    local $_; # make sure we don't spoil it for the outside world
+    local $_; # make sure we don't spoil $_ for the outside world
     my ($interval, $retries, $timeout) = $self->retry;
     my ($host, $port, $username, $password) = $self->remoteHost;
     unless($username && $password)
@@ -306,9 +308,8 @@ sub login(;$)
     if($authenticate eq 'AUTO' || $authenticate eq 'APOP')
     {   if($welcome =~ m#^\+OK .*(<\d+\.\d+\@[^>]+>)#)
         {   my $md5 = Digest::MD5::md5_hex($1.$password);
-            my $response = $self->send($socket, "APOP $username $md5$CRLF")
-	        or return;
-            $connected = OK($response);
+            my $response = $self->send($socket, "APOP $username $md5$CRLF");
+            $connected = OK($response) if $response;
         }
     }
 
@@ -366,11 +367,14 @@ sub status($;$)
     if(OK($uidl))
     {   my @n2uidl;
         $n2uidl[$self->{MTP_messages}] = undef; # optimization, sets right size
+
+        local $_;    # protect global $_
         while(<$socket>)
         {   last if substr($_, 0, 1) eq '.';
-            s#\r?\n$##; m#^(\d+) (.+)#;
-            $n2uidl[$1] = $2;
+            s#\r?\n$##;
+            $n2uidl[$1] = $2 if m#^(\d+) (.+)#;
         }
+
         shift @n2uidl; # make message 1 into index 0
         $self->{MTP_n2uidl} = \@n2uidl;
         delete $self->{MTP_n2length};
