@@ -9,6 +9,8 @@ use lib qw(/home/markov/shared/perl/MimeTypes/lib);
 use base 'Exporter';
 use File::Copy 'copy';
 use List::Util 'first';
+use IO::File;            # to overrule open()
+use FileHandle;          # used in MIME::Body for mime-entity support
 
 our @EXPORT =
   qw/clean_dir copy_dir
@@ -54,6 +56,23 @@ BEGIN {
    $cpy     = File::Spec->catfile('folders', $cpyfn);
 
    ($src, $fn) = $crlf_platform ? ($winsrc, $winfn) : ($unixsrc, $unixfn);
+
+   # IO::File::open() is wrapped, because starting with 1.11 (Perl 5.8.7)
+   # it cannot open files with relative pathnames when tainting checks are
+   # enabled.  I want to test relative folder names!!
+   #
+   # workaround: turn the relative path to an absolute
+   # one here, then untaint it
+   # Idea based on a contribution by Niko Tyni
+
+   my $old_open = \&IO::File::open;
+   no warnings 'redefine';
+   *IO::File::open = sub {
+      my $self = shift;
+      my $file = File::Spec->rel2abs(shift);
+      $file =~ /^(.*)$/;   # untaint
+      $old_open->($self, $1, @_);
+   }
 }
 
 #
@@ -108,6 +127,7 @@ sub copy_dir($$)
 # UNPACK_MBOX2MH
 # Unpack an mbox-file into an MH-directory.
 # This skips message-nr 13 for testing purposes.
+# Blanks before "From" are removed.
 
 sub unpack_mbox2mh($$)
 {   my ($file, $dir) = @_;
@@ -115,6 +135,7 @@ sub unpack_mbox2mh($$)
 
     mkdir $dir, 0700;
     my $count = 1;
+    my $blank;
 
     open FILE, $file or die;
     open OUT, '>', File::Spec->devnull;
@@ -122,10 +143,21 @@ sub unpack_mbox2mh($$)
     while(<FILE>)
     {   if( /^From / )
         {   close OUT;
+            undef $blank;
             open OUT, ">$dir/".$count++ or die;
             $count++ if $count==13;  # skip 13 for test
             next;                    # from line not included in file.
         }
+
+        print OUT $blank
+            if defined $blank;
+
+        if( m/^\015?\012$/ )
+        {   $blank = $_;
+            next;
+        }
+
+        undef $blank;
         print OUT;
     }
 
@@ -200,10 +232,12 @@ sub unpack_mbox2maildir($$)
     open OUT, '>', File::Spec->devnull;
 
     my $last_empty = 0;
+    my $blank;
 
     while(<FILE>)
     {   if( m/^From / )
         {   close OUT;
+            undef $blank;
             my $now      = time;
             my $hostname = hostname;
 
@@ -216,6 +250,15 @@ sub unpack_mbox2maildir($$)
             next;                    # from line not included in file.
         }
 
+        print OUT $blank
+            if defined $blank;
+
+        if( m/^\015?\012$/ )
+        {   $blank = $_;
+            next;
+        }
+
+        undef $blank;
         print OUT;
     }
 
@@ -229,6 +272,7 @@ sub unpack_mbox2maildir($$)
 
 sub compare_lists($$)
 {   my ($first, $second) = @_;
+#warn "[@$first]==[@$second]\n";
     return 0 unless @$first == @$second;
     for(my $i=0; $i<@$first; $i++)
     {   return 0 unless $first->[$i] eq $second->[$i];
